import { useState } from "react";
import Nav from "react-bootstrap/Nav";
import ThumbUpOffAltIcon from "@mui/icons-material/ThumbUpOffAlt";
import ChatBubbleOutlineIcon from "@mui/icons-material/ChatBubbleOutline";
import ShareIcon from "@mui/icons-material/Share";
import GroupIcon from "@mui/icons-material/Group";
import Divider from "@mui/material/Divider";
import Chart from "@/assets/img/chart.jpg";
import { Link } from "@inertiajs/react";
import InsertInvitationIcon from "@mui/icons-material/InsertInvitation";
import * as React from "react";
import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import Typography from "@mui/material/Typography";
import Modal from "@mui/material/Modal";
import OutlinedFlagIcon from "@mui/icons-material/OutlinedFlag";
import PersonAddIcon from "@mui/icons-material/PersonAdd";
import PersonAddDisabledIcon from "@mui/icons-material/PersonAddDisabled";
import ThumbUpIcon from "@mui/icons-material/ThumbUp";
import BookmarkBorderIcon from "@mui/icons-material/BookmarkBorder"; // Icon for un-saved state
import BookmarkIcon from "@mui/icons-material/Bookmark";
import moment from "moment";
import axios from "axios";
import { toast } from "react-toastify";
import {
    TextField,
    IconButton,
    List,
    ListItem,
    InputAdornment,
    CircularProgress,
    TextareaAutosize,
    Dialog,
    DialogTitle,
    DialogContent,
    DialogActions,
    MenuItem,
} from "@mui/material";
import {
    MdSend,
    MdAttachFile,
    MdImage,
    MdVideocam,
    MdMic,
} from "react-icons/md";

import { FiSmile } from "react-icons/fi";
import { FaFacebookF, FaLinkedin } from "react-icons/fa";
import { TbBrandTwitterFilled } from "react-icons/tb";
import { useRef } from "react";
import { Image } from "@mui/icons-material";
import { router, useForm, usePage } from "@inertiajs/react";
import ToastNotifier from "@/Components/ToastNotifier"; // Import toast component
import SocialMediaPosts from "@/Pages/SocialMedia/SocialMediaPosts";

const style = {
    position: "absolute",
    top: "50%",
    left: "50%",
    transform: "translate(-50%, -50%)",

    bgcolor: "background.paper",
    border: "1px solid #2ac",
    borderRadius: "10px",
    boxShadow: 24,
    p: 4,
};
export const FeedCard = ({ single_post, content, hideButtons }) => {
    const { props } = usePage(); // Access Inertia props
    const { success, error, info } = props?.flash || {}; // Get flash messages
    const [postState, setPostState] = useState(single_post);
    const [isSaved, setIsSaved] = useState(single_post.isSaved);
    const [isLikeCount, setIsLikeCount] = useState(single_post.like_count);
    const [isCommentCount, setIsCommentCount] = useState(
        single_post.comment_count
    );
    const [isCommentData, setIsCommentData] = useState(
        single_post.post_comment
    );

    const [url, setUrl] = useState("https://inertiajs.com/");
    const [text, setText] = useState("This is awesome website, Try it NOW.");
    const [showDropdown, setShowDropdown] = useState(false);
    const [notificationDropdown, setNotificationDropdown] = useState(false);
    const [openImage, setOpenImage] = React.useState(false);
    const handleOpenImage = () => setOpenImage(true);
    const handleCloseImage = () => setOpenImage(false);
    const [isPopupOpen, setIsPopupOpen] = useState(false);
    const [reason, setReason] = useState("");
    const [comment, setComment] = useState("");
    const [submitted, setSubmitted] = useState(false);
    const [isFollowing, setIsFollowing] = useState(false);
    const [isLiked, setIsLiked] = useState(single_post.isPostLike);

    // Function to show the popup
    const handleLiClick = () => {
        setIsPopupOpen(true);
    };

    // Function to hide the popup
    const handleClosePopup = () => {
        setIsPopupOpen(false);
    };
    const handleSubmit = () => {
        const reportData = {
            id: single_post.id,
            reason: reason,
            comment: comment,
        };
        //console.log("Form Submitted with Data:", reportData);
        // setIsPopupOpen(false);
        setSubmitted(true);
    };

    const { data, setData, post, processing } = useForm({
        post_id: null,
    });

    const {
        data: commentData,
        setData: setCommentData,
        post: commentPost,
    } = useForm({
        post_id: null,
        content: null,
    });

    const ToggleDropdown = () => {
        setShowDropdown((prev) => !prev);
    };

    const NotificationDropdown = () => {
        setNotificationDropdown((prev) => !prev);
    };

    // const encodedUrl = encodeURIComponent(url);
    // const encodedText = encodeURIComponent(text);
    const shareOptions = [
        {
            icon: <FaFacebookF className="w-7 h-7 mr-2" />,
            name: "Facebook",
            url: `https://www.facebook.com/sharer/sharer.php?url=${url}&text=${text}`,
        },
        {
            icon: <TbBrandTwitterFilled className="w-7 h-7 mr-2" />,
            name: "Twitter",
            url: `https://twitter.com/intent/tweet?url=${url}&text=${text}`,
        },
        {
            icon: <FaLinkedin className="w-7 h-7 mr-2" />,
            name: "LinkedIn",
            url: `https://www.linkedin.com/shareArticle?url=${url}&text=${text}`,
        },
    ];
    const [open, setOpen] = useState(false);
    const handleOpen = () => setOpen(true);
    const handleClose = () => setOpen(false);
    const [loading, setLoading] = useState(false);
    const [imageUrl, setImageUrl] = useState("");
    const [videoUrl, setVideoUrl] = useState("");
    const [messageOpen, setMessageOpen] = useState(false);
    const [message, setMessage] = useState("");
    const fileInputRef = useRef(null);
    const fileVideoRef = useRef(null);
    const handleSend = () => {
        commentData.post_id = single_post.id;
        commentData.content = message;
        /*
    if (commentData) {
      commentPost(route("post.comment"));
      setMessageOpen(!messageOpen);
      setIsCommentCount(7);
    }
    */

        axios
            .post(route("post.comment"), {
                post_id: single_post.id,
                content: message,
            })
            .then((response) => {
                const { message, error, comment_count, post_comment } =
                    response.data;

                if (message) {
                    setMessage();
                    setIsCommentCount(comment_count);

                    setIsCommentData(post_comment);
                    setMessageOpen(!messageOpen);
                }
                if (error) {
                    toast.error(error);
                }
            });
    };
    const handleMessageChange = () => {
        setMessageOpen(!messageOpen);
    };

    const handleFileChange = (event) => {
        const file = event.target.files[0];
        if (file) {
            const url = URL.createObjectURL(file);
            setImageUrl(url);
        }
    };

    const handleVideoChange = (event) => {
        const file = event.target.files[0];
        if (file) {
            const url = URL.createObjectURL(file);
            setVideoUrl(url);
            // Add file upload logic here
        }
    };

    const handleVideoClick = () => {
        fileVideoRef.current.click(); // Trigger the file input click event
    };

    const handleImageClick = () => {
        fileInputRef.current.click(); // Trigger the file input click event
    };

    const likeAction = (id) => {
        // e.preventDefault();
        setIsLiked(!isLiked);
        data.post_id = id;
        //post(route("post.like"), { post_id: id });

        axios.post(route("post.like"), { post_id: id }).then((response) => {
            const { message, error, like_count } = response.data;

            if (message) {
                setIsLikeCount(like_count);
            }
            if (error) {
                toast.error(error);
            }
        });
    };
    const handleFollowClick = async () => {
        // Simulate an API call (you can replace it with actual API logic)
        const id = postState.user_info.id;
        if (!postState.isFollowing) {
            axios.post(route("user.follow"), { id }).then((response) => {
                const { message, error } = response.data;
                if (message) {
                    toast.success(message);
                }
                if (error) {
                    toast.error(error);
                }
            });
            setPostState((prevState) => ({
                ...prevState,
                isFollowing: !prevState.isFollowing,
            }));
            setNotificationDropdown((prev) => !prev);
        } else {
            axios.post(route("user.unfollow"), { id }).then((response) => {
                const { message, error } = response.data;
                if (message) {
                    toast.success(message);
                }
                if (error) {
                    toast.error(error);
                }
            });
            setPostState((prevState) => ({
                ...prevState,
                isFollowing: !prevState.isFollowing,
            }));
            setNotificationDropdown((prev) => !prev);
        }
    };
    const handleSavePost = async () => {
        try {
            const action = isSaved ? "unsave" : "save";
            const route = `/posts/${single_post.id}/${action}`;
            await axios.post(route);
            setIsSaved(!isSaved); // Toggles the state
            setNotificationDropdown((prev) => !prev);
            toast.success(`Post ${action}d successfully`);
        } catch (error) {
            console.error("Error saving post:", error);
            toast.error("An error occurred. Please try again.");
        }
    };

    return (
        <div>
            <div className="mt-3 p-2">
                <div className=" d-flex justify-between">
                    <div className="d-flex gap-2 align-items-center">
                        <span>
                            <GroupIcon />
                        </span>
                        <p className="text-sm fw-bold mb-0">
                            {postState?.user_info?.first_name +
                                " " +
                                postState?.user_info?.last_name}
                        </p>
                    </div>

                    <div className="position-relative d-flex align-items-center justify-center rounded-circle hover:bg-slate-200 px-2 py-1 h-9 w-9">
                    { !hideButtons && <button
                            onClick={NotificationDropdown}
                            type="button"
                            className="rotate-90"
                        >
                            <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="1.5em"
                                height="1.5em"
                                viewBox="0 0 24 24"
                            >
                                <path
                                    fill="#605c5c"
                                    d="M12 14a2 2 0 1 0 0-4a2 2 0 0 0 0 4m-6 0a2 2 0 1 0 0-4a2 2 0 0 0 0 4m12 0a2 2 0 1 0 0-4a2 2 0 0 0 0 4"
                                ></path>
                            </svg>
                        </button>}
                        {notificationDropdown && (
                            <ul
                                className="px-1 p-1 w-[153px] position-absolute top-[28px] right-0 shadow bg-white rounded-xl z-10"
                                role="none"
                            >
                                <li className="list-none hover:bg-slate-200">
                                    <a
                                        role="menuitem"
                                        tabIndex={-1}
                                        className="cursor-pointer d-flex text-gray-700 py-2 text-sm fw-bold block px-2 items-center gap-1"
                                        onClick={handleFollowClick}
                                    >
                                        {postState.isFollowing ? (
                                            <PersonAddDisabledIcon />
                                        ) : (
                                            <PersonAddIcon />
                                        )}

                                        {postState.isFollowing
                                            ? "UnFollow"
                                            : "Follow"}
                                    </a>
                                </li>
                                <li className="list-none hover:bg-slate-200">
                                    <a
                                        onClick={handleSavePost}
                                        role="menuitem"
                                        tabIndex={-1}
                                        className="cursor-pointer d-flex text-gray-700 py-2 text-sm fw-bold block px-2 items-center gap-1"
                                    >
                                        {isSaved ? (
                                            <BookmarkIcon
                                                className="cursor-pointer"
                                                // onClick={handleSavePost}
                                                color="primary"
                                            />
                                        ) : (
                                            <BookmarkBorderIcon
                                                className="cursor-pointer"
                                                // onClick={handleSavePost}
                                            />
                                        )}
                                        <span>
                                            {isSaved ? "Saved" : "Save Post"}
                                        </span>
                                    </a>
                                </li>
                                <li
                                    className="list-none hover:bg-slate-200"
                                    onClick={handleLiClick}
                                >
                                    <a
                                        role="menuitem"
                                        tabIndex={-1}
                                        className="cursor-pointer d-flex text-gray-700 py-2 text-sm fw-bold block px-2 items-center gap-1"
                                    >
                                        <OutlinedFlagIcon />
                                        Report
                                    </a>
                                </li>
                            </ul>
                        )}
                    </div>
                </div>
                <div className="flex gap-2 items-center mb-3">
                    <InsertInvitationIcon className="!text-sm" />
                    <div className="text-xs fw-bold text-slate-400">
                        {postState.created_at}
                    </div>
                </div>
                <div className="row">
                    <div
                        className="text-sm col-md-9"
                        dangerouslySetInnerHTML={{ __html: postState.content }}
                    ></div>
                    {/* {postState.content} */}
                    {postState.image && (
                        <>
                            <div className="col-md-3">
                                <Button onClick={handleOpenImage}>
                                    <img
                                        className="rounded-xl bg-blend-overlay"
                                        src={postState.image}
                                        alt="Chart Image"
                                    />
                                </Button>
                            </div>
                            <Modal
                                open={openImage}
                                onClose={handleCloseImage}
                                aria-labelledby="modal-modal-title"
                                aria-describedby="modal-modal-description"
                            >
                                <Box sx={style}>
                                    <Typography id="modal-modal-title">
                                        <img
                                            className="rounded-xl bg-blend-overlay"
                                            src={postState.image}
                                            alt="Chart Image"
                                        />
                                    </Typography>
                                </Box>
                            </Modal>
                        </>
                    )}
                </div>
                <hr
                    style={{
                        border: "1px solid #333",
                        marginTop: 30,
                    }}
                />
                { !hideButtons && 
                <div className="d-flex mt-3 gap-5 justify-center justify-content-lg-start">
                    <p className="d-flex align-items-center gap-1">
                        {isLiked ? (
                            <ThumbUpIcon
                                className="cursor-pointer"
                                sx={{
                                    fill: "#ff007a !important",
                                }}
                                onClick={() => likeAction(postState.id)}
                            />
                        ) : (
                            <ThumbUpOffAltIcon
                                className="cursor-pointer"
                                onClick={() => likeAction(postState.id)}
                                sx={{
                                    fill: "#ff007a !important",
                                }}
                            />
                        )}
                        {isLikeCount}
                    </p>
                    <p onClick={handleMessageChange}>
                        <ChatBubbleOutlineIcon
                            className="cursor-pointer"
                            sx={{
                                fill: "#ff007a !important",
                            }}
                        />
                        {isCommentCount}
                    </p>

                    <div>
                        <ShareIcon
                            className="cursor-pointer"
                            onClick={handleOpen}
                            sx={{
                                fill: "#ff007a !important",
                            }}
                        />

                        <Modal
                            open={open}
                            onClose={handleClose}
                            aria-labelledby="modal-title"
                            aria-describedby="modal-description"
                        >
                            <Box sx={style}>
                                <Typography
                                    id="modal-title"
                                    variant="h6"
                                    component="h2"
                                >
                                    Share on Social Media
                                </Typography>
                                {shareOptions.map((option) => (
                                    <Button
                                        key={option.name}
                                        href={option.url}
                                        target="_blank"
                                        rel="noopener noreferrer"
                                        variant="contained"
                                        color="primary"
                                        style={{
                                            display: "flex",
                                            alignItems: "center",
                                            justifyContent: "center",
                                            margin: "8px",
                                            padding: "10px 20px",
                                            borderRadius: "8px",
                                            boxShadow: "none",
                                            backgroundColor: "#ff007a",
                                            "&:hover": {
                                                backgroundColor: "#1a2b8f",
                                                color: "#fff !important",
                                            },
                                        }}
                                    >
                                        {option.icon}
                                        <Typography
                                            variant="body1"
                                            style={{ marginLeft: "8px" }}
                                        >
                                            {option.name}
                                        </Typography>
                                    </Button>
                                ))}
                            </Box>
                        </Modal>
                    </div>

                    <Divider />
                </div>}
                {messageOpen && (
                    <>
                        <hr className="mt-3"></hr>
                        <Box
                            sx={{
                                padding: "10px",
                                display: "flex",
                                alignItems: "start",
                                marginTop: "5px",
                                gap: "10px",
                                flexDirection: "column",
                            }}
                        >
                            {isCommentData.map((comment, index) => (
                                <>
                                    {/* <IconButton color="primary"></IconButton> */}
                                    <div className="flex gap-2">
                                        <span className="gradient-color px-2 py-2 h-6 w-6 text-white text-center border border-secondry rounded-circle flex items-center justify-center text-sm">
                                            {comment.user_info.first_name.charAt(
                                                0
                                            )}
                                        </span>
                                        <div>
                                            <div className="flex gap-3 items-center">
                                                <div className="text-sm fw-bold mb-0">
                                                    {
                                                        comment.user_info
                                                            .first_name
                                                    }{" "}
                                                    {
                                                        comment.user_info
                                                            .last_name
                                                    }
                                                </div>
                                                <div className="text-xs fw-bold text-slate-400">
                                                    {moment(
                                                        comment.created_at
                                                    ).format("MMM D, YYYY")}
                                                </div>
                                            </div>

                                            <span className="text-sm mt-2">
                                                {comment.content}
                                            </span>
                                        </div>
                                    </div>
                                </>
                            ))}
                        </Box>
                        <Box
                            sx={{
                                padding: "10px",
                                display: "flex",
                                alignItems: "center",
                            }}
                        ></Box>

                        <div>
                            <Box
                                sx={{
                                    padding: "10px",
                                    borderTop: "1px solid #ddd",
                                    display: "flex",
                                    alignItems: "center",
                                }}
                            >
                                {/* <IconButton color="primary"></IconButton> */}
                                <span className="gradient-color px-2 py-1 h-9 w-9 text-white text-center border border-secondry rounded-circle mr-2">
                                    {postState?.user_info?.first_name.charAt(0)}
                                </span>
                                <div className="relative w-full">
                                    <textarea
                                        className="resize-none w-full h-12 rounded-xl"
                                        value={message}
                                        onChange={(e) =>
                                            setMessage(e.target.value)
                                        }
                                        onKeyDown={(e) =>
                                            e.key === "Enter" && handleSend()
                                        }
                                        placeholder="Type a message"
                                        variant="outlined"
                                        fullWidth
                                        size="small"
                                        sx={{
                                            marginLeft: "10px",
                                            marginRight: "10px",
                                        }}
                                    />
                                    <div className="absolute right-2 inset-y-3">
                                        <MdSend
                                            color="primary"
                                            onClick={handleSend}
                                            className="cursor-pointer hover:text-green-500"
                                            style={{ fontSize: "24px" }}
                                        />
                                    </div>
                                </div>

                                <IconButton
                                    color="primary"
                                    onClick={handleImageClick}
                                >
                                    <input
                                        type="file"
                                        hidden
                                        ref={fileInputRef}
                                        onChange={(e) => handleFileChange(e)}
                                    />
                                    <MdImage style={{ fontSize: "24px" }} />
                                </IconButton>
                                <IconButton
                                    color="primary"
                                    onClick={handleVideoClick}
                                >
                                    <input
                                        type="file"
                                        hidden
                                        ref={fileVideoRef}
                                        onChange={(e) => handleVideoChange(e)}
                                    />
                                    <MdVideocam />
                                </IconButton>
                            </Box>
                            <div>
                                <div className="d-flex">
                                    <div
                                        className="d-flex"
                                        style={{ width: "50%" }}
                                    >
                                        {imageUrl !== "" && (
                                            <div
                                                className="d-flex flex-column justify-content-center align-items-center"
                                                style={{ width: "100%" }}
                                            >
                                                <img
                                                    src={imageUrl}
                                                    alt="Image"
                                                    style={{ width: "100%" }}
                                                />
                                            </div>
                                        )}
                                    </div>
                                    <div
                                        className="d-flex"
                                        style={{ width: "50%" }}
                                    >
                                        {videoUrl !== "" && (
                                            <div
                                                className="d-flex flex-column justify-content-center align-items-center"
                                                style={{ width: "100%" }}
                                            >
                                                <video
                                                    src={videoUrl}
                                                    alt="Video"
                                                    controls
                                                    style={{ width: "100%" }}
                                                />
                                            </div>
                                        )}
                                    </div>
                                </div>
                            </div>
                        </div>
                    </>
                )}
            </div>
            <Dialog
                open={isPopupOpen}
                onClose={handleClosePopup}
                fullWidth
                maxWidth="sm"
                sx={{ borderRadius: "20px" }}
            >
                {/* Dialog Title */}
                <DialogTitle backgroundColor="#f4f5fa">
                    <Typography variant="h6" fontWeight="bold">
                        Report Abuse
                    </Typography>
                </DialogTitle>

                {/* Dialog Content */}
                <DialogContent>
                    {/* Info Text */}
                    {!submitted ? (
                        <>
                            <Box mb={2} mt={3}>
                                <Typography
                                    variant="body1"
                                    fontSize={14}
                                    color="#090b34"
                                    lineHeight="20px"
                                >
                                    Please note: We take abuse reports very
                                    seriously. Serious or repeat offenders can
                                    get their accounts permanently blocked. Here
                                    is our policy on{" "}
                                    <a
                                        href="#"
                                        style={{
                                            color: "blue",
                                            textDecoration: "underline",
                                        }}
                                    >
                                        what counts as abuse?
                                    </a>
                                </Typography>
                            </Box>

                            {/* Reported Post Preview */}
                            <Box
                                p={2}
                                mb={2}
                                border="1px solid #ddd"
                                borderRadius="8px"
                                bgcolor="#f9f9f9"
                            >
                                <Typography variant="body2" fontWeight="bold">
                                    You are reporting this post:
                                </Typography>
                                <Box display="flex" alignItems="center" mt={1}>
                                    <img
                                        src={postState.image}
                                        alt="Post Thumbnail"
                                        style={{
                                            width: 50,
                                            height: 50,
                                            marginRight: 10,
                                            borderRadius: "4px",
                                        }}
                                    />
                                    <Typography variant="body2">
                                        <strong>
                                            {" "}
                                            {postState?.user_info?.name}
                                        </strong>
                                        <br />
                                        {postState.content}
                                    </Typography>
                                </Box>
                            </Box>

                            {/* Reason Dropdown */}
                            <TextField
                                label="Reason *"
                                select
                                fullWidth
                                value={reason}
                                onChange={(e) => setReason(e.target.value)}
                                helperText="Select the reason why you believe this post is inappropriate."
                            >
                                <MenuItem value="Breaks Club Rules">
                                    Breaks Club Rules
                                </MenuItem>
                                <MenuItem value="Commercial Spam">
                                    Commercial Spam
                                </MenuItem>
                                <MenuItem value="Irrelevant Stock Tags">
                                    Irrelevant Stock Tags
                                </MenuItem>
                                <MenuItem value="Copyright Violation">
                                    Copyright Violation
                                </MenuItem>
                                <MenuItem value="Abusive">Abusive</MenuItem>
                                <MenuItem value="Other">Others</MenuItem>
                            </TextField>

                            {/* Comment Field */}
                            <TextField
                                label="Comment"
                                multiline
                                rows={4}
                                fullWidth
                                margin="normal"
                                placeholder="Feel free to elaborate why this post is inappropriate."
                                value={comment}
                                onChange={(e) => setComment(e.target.value)}
                                sx={{
                                    "& .MuiOutlinedInput-root": {
                                        "&.Mui-focused": {
                                            boxShadow: "none", // Apply blue shadow on focus
                                        },
                                    },
                                }}
                            />
                        </>
                    ) : (
                        // If the form has been submitted, show a thank you message
                        <Box textAlign="center" marginTop={5}>
                            <Typography
                                variant="h6"
                                fontWeight="bold"
                                gutterBottom
                            >
                                Thank You for Your Report!
                            </Typography>
                            <Typography variant="body1">
                                We take abuse reports seriously. Our team will
                                review this post and take appropriate action.
                            </Typography>
                        </Box>
                    )}
                </DialogContent>

                {/* Dialog Actions */}
                <DialogActions>
                    {!submitted ? (
                        <>
                            <Button
                                onClick={handleClosePopup}
                                color="secondary"
                            >
                                Cancel
                            </Button>
                            <Button
                                onClick={handleSubmit}
                                variant="contained"
                                color="primary"
                            >
                                Submit
                            </Button>
                        </>
                    ) : (
                        // Only show the Close button when the report is submitted
                        <Button
                            onClick={handleClosePopup}
                            variant="contained"
                            color="primary"
                        >
                            Close
                        </Button>
                    )}
                </DialogActions>
            </Dialog>
        </div>
    );
};
